@@ -9,15 +9,15 @@
 #  ifndef IGRAPH_EXPORT
 #    ifdef igraph_EXPORTS
         /* We are building this library */
-#      define IGRAPH_EXPORT __attribute__((visibility("default")))
+#      define IGRAPH_EXPORT 
 #    else
         /* We are using this library */
-#      define IGRAPH_EXPORT __attribute__((visibility("default")))
+#      define IGRAPH_EXPORT 
 #    endif
 #  endif
 
 #  ifndef IGRAPH_NO_EXPORT
-#    define IGRAPH_NO_EXPORT __attribute__((visibility("hidden")))
+#    define IGRAPH_NO_EXPORT 
 #  endif
 #endif
 
@@ -33,6 +33,7 @@
 #  define IGRAPH_DEPRECATED_NO_EXPORT IGRAPH_NO_EXPORT IGRAPH_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef IGRAPH_NO_DEPRECATED
 #    define IGRAPH_NO_DEPRECATED
